.. |pypi-version| image:: https://img.shields.io/pypi/v/django-helper-kit?label=PyPI%20Version&color=4BC51D
   :alt: PyPI Version
   :target: https://pypi.org/projects/django-helper-kit/

.. |pypi-downloads| image:: https://img.shields.io/pypi/dm/django-helper-kit?label=PyPI%20Downloads&color=037585
   :alt: PyPI Downloads
   :target: https://pypi.org/projects/django-helper-kit/

django-helper-kit
#################

|pypi-version| |pypi-downloads|

Description
***********

This package contains useful utilities that can be used in a Django environment.

It is also supporting package for:
 - `django-datatables-kit`
 - other django packages in the future


Note: This is an alpha version, and things may change quite a bit.